import router from './router'
import store from './store'
import { Message } from 'element-ui'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
import { getToken } from '@/utils/auth'
import { isRelogin } from '@/utils/request'
import Cookies from 'js-cookie'
NProgress.configure({ showSpinner: false })

const whiteList = ['/web/htm/systemmanage/login', '/register','/userIndex','/userIndex1','/zhengshuSearch','/mmzh','/loginJly','/loginQy']

router.beforeEach((to, from, next) => {
  NProgress.start()
  if (getToken()) {
    to.meta.title && store.dispatch('settings/setTitle', to.meta.title)
    /* has token*/ 
    if (to.path === '/web/htm/systemmanage/login' || to.path === '/userIndex') {
      next({ path: '/index' })
      NProgress.done()
    } else {
      if (store.getters.roles.length === 0) {
        isRelogin.show = true
        // 判断当前用户是否已拉取完user_info信息
        store.dispatch('GetInfo').then(() => {
          isRelogin.show = false
          store.dispatch('GenerateRoutes').then(accessRoutes => {
            // 根据roles权限生成可访问的路由表
            router.addRoutes(accessRoutes) // 动态添加可访问路由表
            next({ ...to, replace: true }) // hack方法 确保addRoutes已完成
          })
        }).catch(err => {
            store.dispatch('LogOut').then(() => {
              Message.error(err)
              // next({ path: '/' })
			  if(Cookies.get('type')=='2'){
			  	next({ path: '/web/htm/systemmanage/login' })
			  }else{
			  	next({ path: '/userIndex' })
			  }
            })
          })
      } else {
        next()
      }
    }
  } else {
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免登录白名单，直接进入
      next()
    } else {
      // next(`/userIndex`) // 否则全部重定向到登录页
	  if(Cookies.get('type')=='2'){
	  	next({ path: '/web/htm/systemmanage/login' })
	  }else{
	  	next({ path: '/userIndex' })
	  }
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  NProgress.done()
})
